@@ -1,5 +1,5 @@
 import unittest
-from CredentialManager import base_path as start_dir
+from src.CredentialManager import base_path as start_dir
 
 
 
